.. _get help:

Get Help
========

All questions or bug reports about our software are welcome!

- First, please check the :ref:`FAQ<faq>` to see if your question is already answered.
- If you are facing bugs or troubles with MotifScan, please open an `issue`_ on Github.

.. _issue: https://github.com/shao-lab/MotifScan/issues
